@@ -1,6 +1,6 @@
 from sys import platform
-from linux_run import LR
-from win_run import WR
+from trinity4bci.linux_run import LR
+from trinity4bci.win_run import WR
 
 def RUN():
     if platform == "linux" or platform == "linux2":
